# python-ldap2jira

Set of utilities for finding jira accounts with LDAP check and optional file map.

[![Pypi Upload](https://github.com/RedHat-Eng-PGM/python-ldap2jira/actions/workflows/python-publish.yml/badge.svg)](https://github.com/RedHat-Eng-PGM/python-ldap2jira/actions/workflows/python-publish.yml)

https://pypi.org/project/ldap2jira/
